import { DatePipe } from '@angular/common';
import {
  Component,
  EventEmitter,
  inject,
  Output,
  resource,
} from '@angular/core';
import { TaskService } from '../service/task-service';

@Component({
  selector: 'app-todo-table',
  imports: [DatePipe],
  templateUrl: './todo-table.html',
  styleUrl: './todo-table.css',
})
export class TodoTable {
  public tasks = resource({
    loader: async (): Promise<Task[]> => {
      const response = await fetch('http://localhost:2000/api/tasks');
      return (await response.json()) as Task[];
    },
  });
  private taskService: TaskService = inject(TaskService);

  @Output() editTaskEvent = new EventEmitter<Task>();

  editTask(task: Task) {
    this.editTaskEvent.emit(task);
  }

  deleteTask(task: Task) {
    this.taskService.deleteTask(task).then(() => this.tasks.reload());
  }

  toggleTaskDoneStatus(task: Task) {
    this.taskService.toggleTaskDoneStatus(task).then(() => this.tasks.reload());
  }
}
